import logging
import os
import sys
import time
from datetime import datetime, timedelta
from prometheus_client import start_http_server, Counter

from src.utils.reporter import MetricsClient
from src.utils.utils import get_athena_query_results, convert_statistics_csv, org_data_to_S3

logging.basicConfig(stream=sys.stdout, level=logging.INFO)

CDCA_DATABASE = os.getenv("CDCA_DATABASE", "cdca")
CDCA_QUERY_RESULT = os.getenv("CDCA_QUERY_RESULT", "cdca-policy-suggest-analytics-dev-athena-outputs")
ORG_DAILY_BUCKET = os.getenv("ORG_DAILY_BUCKET", "kcdev01-mdr-reporting-job-infra-daily-alert")
PROMETHEUS_METRICS_PORT = os.environ.get("PROMETHEUS_PORT", "9090")


def get_yesterdays_date():
    d = datetime.utcnow() - timedelta(days=1)
    day = d.day
    month = d.month
    # day, month = 9,3
    year = d.year
    fill_date = "{}-{:02d}-{:02d}".format(year, month, day)
    return fill_date


def main():
    metric_client = MetricsClient('mdr_reporting_job', PROMETHEUS_METRICS_PORT)

    org_objects = {}
    with open('./src/sqls/daily_query.sql', 'r') as daily_query_file:
        stat_results = get_athena_query_results(database=CDCA_DATABASE, query=daily_query_file.read(),
                                                query_bucket=CDCA_QUERY_RESULT)
        convert_statistics_csv(stat_results, org_objects, metric_client, 'daily')
    logging.info(f"Starting daily org statistics with [{len(org_objects)}] entries")
    org_data_to_S3(org_objects, bucket=ORG_DAILY_BUCKET, file_name=get_yesterdays_date())
    logging.info("S3 transfer complete!")


if __name__ == "__main__":
    main()
